@@ -6,7 +6,7 @@ import Base: &, *, +, -, <, <<, <=, ==, >>, >>>, |, ~, AbstractFloat, add_with_o
              bitstring, bswap, checked_abs, count_ones, div, flipsign, hash, isodd, iseven,
              leading_zeros,
              mod, mul_with_overflow, ndigits0zpb, peek, promote_rule, read, rem, signed,
-             sub_with_overflow, trailing_zeros, typemax, typemin, unsigned, write, xor
+             sub_with_overflow, trailing_zeros, typemax, typemin, signed, unsigned, write, xor
 
 using Base: GenericIOBuffer, add_int, and_int, ashr_int, bswap_int, checked_sadd_int,
             checked_sdiv_int, checked_smul_int, checked_srem_int, checked_ssub_int,
@@ -15,7 +15,7 @@ using Base: GenericIOBuffer, add_int, and_int, ashr_int, bswap_int, checked_sadd
             ndigits0z, ndigits0znb, neg_int, not_int, or_int, shl_int, sitofp, sle_int,
             slt_int, sub_int, uinttype, uitofp, ule_int, ult_int, xor_int
 
-using Base.GMP: ispos, Limb
+using Base.GMP: Limb
 
 using Core: bitcast, checked_trunc_sint, checked_trunc_uint, sext_int,
             trunc_int, zext_int
@@ -39,6 +39,12 @@ if VERSION >= v"1.5"
     import Base: bitrotate
 end
 
+if isdefined(Base.GMP, :ispos)
+    ispos(x) = Base.GMP.ispos(x)
+else
+    ispos(x) = Base.ispositive(x)
+end
+
 
 # * types definition & aliases
 
@@ -167,10 +173,13 @@ typemax(::Type{T}) where {T<:XBS} = bitcast(T, typemax(uinttype(T)) >> 1)
 
 # * conversions, promotions
 
-# ** signed / unsigned
+# ** signed
+signed(::Type{T}) where T<:XBI = typeof(convert(Signed, zero(T)))
+signed(x::T) where T<:XBI = reinterpret(signed(T), x)
 
-signed(x::XBU) = reinterpret(typeof(convert(Signed, zero(x))), x)
-unsigned(x::XBS) = reinterpret(typeof(convert(Unsigned, zero(x))), x)
+# ** unsigned
+unsigned(::Type{T}) where T<:XBI = typeof(convert(Unsigned, zero(T)))
+unsigned(x::T) where T<:XBI = reinterpret(unsigned(T), x)
 
 # ** integers
 
